import cx from 'classnames'
import React, { PropTypes } from 'react'

import {
  customPropTypes,
  getElementType,
  getUnhandledProps,
  META,
  useKeyOnly,
} from '../../lib'

/**
 * An ad displays third-party promotional content.
 */
function Advertisement(props) {
  const {
    centered,
    children,
    className,
    test,
    unit,
  } = props

  const classes = cx(
    'ui',
    unit,
    useKeyOnly(centered, 'centered'),
    useKeyOnly(test, 'test'),
    'ad',
    className,
  )
  const rest = getUnhandledProps(Advertisement, props)
  const ElementType = getElementType(Advertisement, props)

  return <ElementType {...rest} className={classes} data-text={test}>{children}</ElementType>
}

Advertisement._meta = {
  name: 'Advertisement',
  type: META.TYPES.VIEW,
}

Advertisement.propTypes = {
  /** An element type to render as (string or function). */
  as: customPropTypes.as,

  /** Center the advertisement. */
  centered: PropTypes.bool,

  /** Primary content. */
  children: PropTypes.node,

  /** Additional classes. */
  className: PropTypes.string,

  /** Text to be displayed on the advertisement. */
  test: PropTypes.oneOfType([
    PropTypes.bool,
    PropTypes.number,
    PropTypes.string,
  ]),

  /** Varies the size of the advertisement. */
  unit: PropTypes.oneOf([
    'medium rectangle', 'large rectangle', 'vertical rectangle', 'small rectangle',
    'mobile banner', 'banner', 'vertical banner', 'top banner', 'half banner',
    'button', 'square button', 'small button',
    'skyscraper', 'wide skyscraper',
    'leaderboard', 'large leaderboard', 'mobile leaderboard', 'billboard',
    'panorama',
    'netboard',
    'half page',
    'square', 'small square',
  ]).isRequired,

}

export default Advertisement
